***********************************************************************
* try to repicate Pitt 1999 tables using Land file 13AR1
* also produces weighted lowess figures of unit land values 
* try file 13AR1.DTA - landed assets
* see also Pitt1999_Table3_old

*****************************************************
* analyse land unit values 
*****************************************************

*** run down to *** in one block 
qui {
clear all
use "${datapath1}\ROSTERR1.DTA", clear
sort nh /*preparation for merging: nh is the identifying variable in both STATA files: 13AR1 and ROSTERR1*/
tempfile t
save `t'
use if halaid ~= 6 using "${datapath1}\13AR1.DTA", clear 
label define halaid 1 "homestead land" 2 "pond/orchard/bamboo" 3 "Own cultivation" 4 "Sharecrop out" 5 "Own land other" 6 "total value of land"
label val halaid 
label var halaid "land types"

* define variables by type 
levelsof halaid, local(type)
foreach v in `type' {
	gen halab_`v' = halab if halaid == `v'
	gen halaa_`v' = halaa if halaid == `v'
}
 
foreach i in a b {
	forval j = 1/5 {
		local label : label halaid `j' 
		label var hala`i'_`j' "`label'"
	}
}
		
sort nh /*preparation for merging: nh is the identifying variable in both STATA files: 13AR1 and ROSTERR1*/
collapse (sum) halab halab_* halaa halaa_* halabp halabi halabg halabd halabo halaap halaai halaag halaad halaao, by(nh) // all land
label define halaid 1 "homestead land" 2 "pond/orchard/bamboo" 3 "Own cultivation" 4 "Sharecrop out" 5 "Own land other" 6 "total value of land", modify
forval i = 1/5 {
	label var halab_`i' "`:label halaid `i''"
}
tempfile t2
save `t2'
* create file of total value of land
use if halaid == 6 using "${datapath1}\13AR1.DTA", clear 
gen totvalb = halab 
gen totvala = halaa 
collapse (sum) totvalb totvala (count) n = pid, by(nh)	// include all - several households have 
sort nh
/*merge both data sets, be in 06AR1 STATA window:*/
merge nh using `t2' `t'
tab _merge
ren _merge _m_owncult
sort nh
preserve 
	use if wave == 1 using "${datapath1}\wght123.dta", clear
	sort nh
	tempfile t
	save `t', replace
restore
merge nh  using `t'
tab _merge
drop _merge

* get credit and membership from cum_loans
preserve
	use wave nh csg csgpj csgpn csgpc csg mproglv_rpj fproglv_rpj if wave == 1 ///
		using "${workingpath}\cum_loans_person_inc86_hh_.dta", clear
	drop wave
	sort nh 
	tempfile t 
	save `t', replace
restore
sort nh
merge nh using `t'
tab _merge
drop _merge

* merge with 06AR1 to use proportions of irrigated, near and far land

sort nh
preserve
	use "${datapath1}\06AR1.DTA", clear
* although nh & pid in file only one observation per household
	sort nh
	tempfile t
	save `t'
restore
merge nh using `t'
tab _merge
drop _merge

qui des using "${datapath1}\06AR1.DTA", varlist
local vars =r(varlist)
foreach v in `vars' {
	cap confirm numeric variable `v' 
	if !_rc {
		replace `v' = 0 if `v' == .
	}
}	
***************************
* total value of assets   *
***************************
preserve
	use "${workingpath}\OutcomeVar_NonLandAssets_hh.dta", clear
	keep nh wave nonlandasset nonlandwomen lnnonlandwomen nonlandmen lnnonlandmen cssv cssgfv equipment transport other 
*	ren wave round
	sort nh wave // round
	tempfile t 
	save `t', replace
restore
sort nh wave
merge 1:1 nh wave using `t'
tab _merge
keep if _merge == 3
drop _merge

* get Pitt non-target variable
preserve
	use nh round nontrgth creditf creditm loghland if round == 1 ///
		using "${pittpath}\PKexp.dta", clear
	gen hland = exp(loghland)
	drop round 
	sort nh
	tempfile t 
	save `t', replace
restore
sort nh
merge 1:1 nh using `t'
tab _merge
ren _merge _merge_pkexp

gen TotOwned =   flnt + flft	// sum of near and far total
gen OwnedCultivated = TotOwned - florc

* correct halab - replace 
gen halab_adj = halab
replace halab_adj = halaa if progid >= 4	// seems that halab was missing for non-participants

gen totvalb_adj = totvalb 
replace totvalb_adj = totvala if progid >= 4

* replace halab for non-participant households
forval i = 1/5 {
	replace halab_`i' = halaa_`i' if progid >= 4
}
* replace missing values with zeros
foreach v in  halab halab_1 halab_2 halab_3 halab_4 halab_5 halaa halaa_1 halaa_2 halaa_3 halaa_4 halaa_5 {
	replace `v' = 0 if `v' == .	
}

gen CultivableLandOwned = halab_3 + halab_4
gen fcredit = fproglv_rpj > 0
gen mcredit = mproglv_rpj > 0

*** thana dummy variables run to ***
levelsof thanaid, local(thana)
foreach t in `thana' {
	gen t_`t' = thanaid == `t'
}

* compute unit value of land 
gen landbunitval = totvalb / halab 
gen landaunitval = totvala/ halaa 

gen landbsq = halab ^ 2
gen landasq = halaa ^ 2

gen halabsq = halab_adj ^ 2

* compute unit value of land 
gen landb_adjunitval = totvalb_adj / halab_adj 
*gen nontrgth = halab_adj >= 50 & participant == 0
gen target = halab_adj < 50
gen target2 = totvalb_adj < 40000

* participants
gen participant = progid <= 3	// participates in any of BRAC, BRDB or GB 

* nontarget by land area
gen nontar = participant == 0 & halab_adj >= 50

* table 3 col 1?
*Land unit values before survey

* eligibility based on culitivable land 
gen mistarget_adj = (halab_3 + halab_4) > 50 & participant == 1

* look at distribution of irrigated land ...
gen unitval06 =  fltv / TotOwned
gen p_ni :  "proportion near irrigated" =  flni/ TotOwned
gen p_nni : "proportion near not irrigated" =  flnni/ TotOwned
gen p_fi : "proportion far irrigated" =  flfi/ TotOwned
gen p_fni : "proporiton far not irrigated" =  flfni/ TotOwned

gen TotOwnedsq = TotOwned ^ 2

* can we use uland bvalues from 06AR?
* since I set values to zero if missing probably not right.
gen t_ir = flni + flfi
gen t_nir = flnni + flfni
gen p_ir = t_ir / TotOwned
gen p_nir = t_nir / TotOwned

forval i = 1/5 {
	gen p_halab_`i' = 100 * halab_`i' / halab_adj
	replace p_halab_`i' = 0 if p_halab_`i' == .
	local lab : var l halab_`i'
	label var p_halab_`i' "`lab'"
}
/*
preserve
	keep nh totvalb halab_* totvalb_adj totvala landbunitval landaunitval TotOwned OwnedCultivated fltv unitval06 p_ni p_nni p_fi p_fni TotOwnedsq
	save "${workingpath}\table5.csv", replace // land_values.dta", replace
restore
*/

* results reported in text 
**************************************************************************************************************
* table 5
**************************************************************************************************************
g nontarget = 1 - target
g nonpart = 1 - participant
label define nont  0 "target" 1 "nontarget"
label define nonp  0 "participant" 1 "nonparticipant"
label val nontarget nont
label val nonpart nonp
label var p_halab_1 "house land"


} // end quiet

noisily table nontarget nonpart [pweight = weight], c(mean p_halab_1 mean p_halab_3 mean p_halab_4 mean landb_adjunitval) ///
	f(%8.2f)
* copy results to Excel and then to Word

qui {

egen t = group(nontarget nonpart) , label
mat results = J(4,4,.)
local i = 1
foreach v in  p_halab_1 p_halab_3 p_halab_4 landb_adjunitval {
	qui reg `v' ibn.t [weight = weight], cluster(vill) nocons
	eststo _`i'
	forval j = 1/4 {
		mat results[`i', `j' ] = _b[`j'.t]
	}
	local ++i
}
mat colnames results = "target participant" "target nonparticipant" "nontarget participant" "nontarget nonparticipant"
mat rownames results = "proportion of homestead" "proportion of own cultivation" "proportion sharecroped out" "land unit value (tk/d)"
esttab matrix(results, fmt(2 2 2 2) ) using "${workingpath}\table5.csv", replace  title("Table 5: Land and land value by Target and Participant Status")
} // end quiet

/*
tabstat p_halab_1 p_halab_3 p_halab_4 landb_adjunitval [weight = weight], by(t) s(mean ) f(%8.2f) save
statsmat p_halab_1 p_halab_3 p_halab_4 landb_adjunitval [weight = weight] , s(mean) ma
*/
 

* Needs Ian Watson's "tabout.ado"
*******************************************
***** NOTE - the output file is .txt *****
*******************************************
/*
tabout t  using "${workingpath}\table5.txt" , ///
	c(mean p_halab_1 mean p_halab_3 mean p_halab_4 mean landb_adjunitval) f(0c)  sum  replace  npos(both) clab

mean2 p_halab_1 p_halab_3 p_halab_4 landb_adjunitval  using "${workingpath}\table5.txt" /// // [weight = weight] 
	 , over(t) cat(tar_part tar_nonpart nontar_part nontar_nonpart) replace
*/
/*
preserve
	keep weight t p_h*
	foreach v of var * {
		local l`v' : variable label `v'
		if `"`l`v''"' == "" {
			local l`v' "`v'"
		}
	 }

	collapse p_h* [weight = weight], by(t)
	foreach v of var * {
		label var `v' "`l`v''"
		replace `v' = round(`v', 0.01)
	}	
restore
*/
/*
label variable  landb_adjunitval "land unit value"
local list 
foreach v in p_halab_1 p_halab_3 p_halab_4 landb_adjunitval {
	local lab : variable label `v'
	local lab = strtoname("`lab'")
	gen l`v'= `v'
	ren l`v' `lab'
	local list `list' `lab'
}
tabstat `list'  [weight = weight], by(t) save total
tabstatmat t
esttab matrix(t, fmt(2 2 2 2)) using "${workingpath}\table5.csv", replace

drop homestead_land- lp_halab_1
*/

/*
estout _1 _2 _3 _4 using "${workingpath}\table5.csv", replace cells(b(fmt(%8.2f)))  ///
	mlabels("proportion of homestead" "proportion of own cultivation" "proportion sharecroped out" "land unit value") ///
	varl(1.t "target participant" 2.t "target nonparticipant" 3.t "nontarget participant" 4.t "nontarget nonparticipant") ///
	transpose
*/

qui {

******************************************************************************************************************
* Figures 4 & 5 
* compare unit values of land by locally weighted regression
******************************************************************************************************************

* lowess - NOT REPORTED
gen lhalab = ln(halab_adj)
* run Roodmans wlowess
do "${progpath}\mp_routines.do"
replace lhalab = cond(lhalab >= 0, lhalab, 0)
sort lhalab
gen tp_cat : "target participant" = target == 1 & participant == 1 
replace  tp_cat = 2 if target == 0 & participant == 1 
replace  tp_cat = 3 if target == 1 & participant == 0 
replace  tp_cat = 4 if target == 0 & participant == 0 
* restrict sample to unit values < 5000 tk/decimal
wlowess landb_adjunitval lhalab if target == 1 & participant == 1 & landb_adjunitval < 5000 [pw=weight], xb(low_halab_1_xb) stdp(low_halab_1_stdp)
wlowess landb_adjunitval lhalab if target == 0 & participant == 1 & landb_adjunitval < 5000 [pw=weight], xb(low_halab_2_xb) stdp(low_halab_2_stdp)
wlowess landb_adjunitval lhalab if target == 1 & participant == 0 & landb_adjunitval < 5000 [pw=weight], xb(low_halab_3_xb) stdp(low_halab_3_stdp)
wlowess landb_adjunitval lhalab if target == 0 & participant == 0 & landb_adjunitval < 5000 [pw=weight], xb(low_halab_4_xb) stdp(low_halab_4_stdp)

forval i = 1/4 {
		gen low_halab_`i'_CIL = low_halab_`i'_xb - 1.96 * low_halab_`i'_stdp
		gen low_halab_`i'_CIU = low_halab_`i'_xb + 1.96 * low_halab_`i'_stdp
}

*****************************************************
** figure 4
*****************************************************
twoway rarea low_halab_1_CIU low_halab_1_CIL lhalab, fcolor(green) fintensity(inten30) astyle(ci) || ///
	rarea low_halab_2_CIU low_halab_2_CIL lhalab, fcolor(blue) fintensity(inten30) astyle(ci) || ///
	rarea low_halab_3_CIU low_halab_3_CIL lhalab, fcolor(red) fintensity(inten30) astyle(ci) || ///
	rarea low_halab_4_CIU low_halab_4_CIL lhalab, fcolor(yellow) fintensity(inten30) astyle(ci) || ///
	scatter landb_adjunitval lhalab if landb_adjunitval < 5000 & tp_cat == 1, mcolor(green)  msize(tiny) msymbol(circle..)  || /// // 
	scatter landb_adjunitval lhalab if landb_adjunitval < 5000 & tp_cat == 2, mcolor(blue)  msize(tiny) msymbol(circle..)  || /// // 
	scatter landb_adjunitval lhalab if landb_adjunitval < 5000 & tp_cat == 3, mcolor(red)  msize(tiny) msymbol(circle..)  || /// // 
	scatter landb_adjunitval lhalab if landb_adjunitval < 5000 & tp_cat == 4, mcolor(yellow)  msize(tiny) msymbol(circle..)  /// // 
	xline(`=ln(50)', lwidth(vvthin) lpattern(dash))  ///
	title("unit value of land by land owned before MF/at time of survey" , margin(medsmall) orient(horizontal) size(medium) span) scheme(s1color) ///
	plotregion(style(none) margin(zero)) ysize(4) xsize(6.5) ///
	ytitle("tk/decimal") ///
	yscale(lpattern(blank)) xscale(range(0 2.060514)) xtitle("land owned (ln(decimals))") ///
	note("weighted lowess regression estimates", size(small)) ///
	legend(label(1 "target participant") label(2 "non-target participant") label(3 "target non-participant") label(4 "non-target non-participant") order(1 2 3 4)) ///
	name(figure4, replace)  saving("${workingpath}\figure4.gph", replace)

******************************************************
** figure 5
******************************************************
* use nontrgth
gen tp_cata : "target participant" = target == 1 & participant == 1 
replace  tp_cata = 2 if target == 0 & participant == 1 
replace  tp_cata = 3 if target == 1 & participant == 0 
replace  tp_cata = 4 if nontrgth == 1

* restrict sample to unit values < 5000 tk/decimal
wlowess landb_adjunitval lhalab if tp_cata == 1 & landb_adjunitval < 5000 [pw=weight], xb(low_halab_a1_xb) stdp(low_halab_a1_stdp)
wlowess landb_adjunitval lhalab if tp_cata == 2 & landb_adjunitval < 5000 [pw=weight], xb(low_halab_a2_xb) stdp(low_halab_a2_stdp)
wlowess landb_adjunitval lhalab if tp_cata == 3 & landb_adjunitval < 5000 [pw=weight], xb(low_halab_a3_xb) stdp(low_halab_a3_stdp)
wlowess landb_adjunitval lhalab if tp_cata == 4 & landb_adjunitval < 5000 [pw=weight], xb(low_halab_a4_xb) stdp(low_halab_a4_stdp)

forval i = 1/4 {
		gen low_halab_a`i'_CIL = low_halab_a`i'_xb - 1.96 * low_halab_a`i'_stdp
		gen low_halab_a`i'_CIU = low_halab_a`i'_xb + 1.96 * low_halab_a`i'_stdp
}

* restrict to unit values < 5000
twoway rarea low_halab_a1_CIU low_halab_a1_CIL lhalab, fcolor(green) fintensity(inten30) astyle(ci) || ///
	rarea low_halab_a2_CIU low_halab_a2_CIL lhalab, fcolor(blue) fintensity(inten30) astyle(ci) || ///
	rarea low_halab_a3_CIU low_halab_a3_CIL lhalab, fcolor(red) fintensity(inten30) astyle(ci) || ///
	rarea low_halab_a4_CIU low_halab_a4_CIL lhalab, fcolor(yellow) fintensity(inten30) astyle(ci) || ///
	scatter landb_adjunitval lhalab if landb_adjunitval < 5000 & tp_cata == 1, mcolor(green)  msize(vsmall) msymbol(circle..)  || /// // 
	scatter landb_adjunitval lhalab if landb_adjunitval < 5000 & tp_cata == 2, mcolor(blue)  msize(vsmall) msymbol(circle..)  || /// // 
	scatter landb_adjunitval lhalab if landb_adjunitval < 5000 & tp_cata == 3, mcolor(red)  msize(vsmall) msymbol(circle..)  || /// // 
	scatter landb_adjunitval lhalab if landb_adjunitval < 5000 & tp_cata == 4, mcolor(yellow)  msize(vsmall) msymbol(circle..)  /// // 
	xline(`=ln(50)', lwidth(vvthin) lpattern(dash))  ///
	title("unit value of land by land owned before MF/at time of survey" , margin(medsmall) orient(horizontal) size(medium) span) scheme(s1color) ///
	plotregion(style(none) margin(zero)) ysize(4) xsize(6.5) ///
	ytitle("tk/decimal") ///
	yscale(lpattern(blank)) xscale(range(0 2.060514)) xtitle("land owned (ln(decimals))") ///
	note("Note: land unit value > 5000tk/decimal excluded" "weighted lowess regression estimates", size(small)) ///
	legend(label(1 "target participant") label(2 "mis-target") label(3 "target non-participant") label(4 "non-nontrgth == 1") order(1 2 3 4)) ///
	name(figure5, replace)  saving("${workingpath}\figure5.gph", replace)



* trial regressions
reg landb_adjunitval halab_adj c.halab_adj#c.halab_adj  mistarget_adj i.thana [weight = weight] // all villages
reg landb_adjunitval halab_adj c.halab_adj#c.halab_adj  mistarget_adj participant i.thana [weight = weight] 
reg landb_adjunitval halab_adj  c.halab_adj#c.halab_adj  mistarget_adj participant nontrgth i.thana [weight = weight] 
test mistarget_adj = nontrgth
reg landb_adjunitval halab_adj  c.halab_adj#c.halab_adj  mistarget_adj nontrgth i.thana [weight = weight] 
test mistarget_adj = nontrgth
reg landb_adjunitval halab_adj  c.halab_adj#c.halab_adj  mistarget_adj participant nontrgth i.thana [weight = weight] if thana <= 24
*margins, at(halab_adj = 100) by(participant mistarget_adj nontrgth)
test mistarget_adj = nontrgth


*********************************************************
** table 6
*********************************************************
forval i = 1/5 {
	qui{
		local j = cond(mod(`i', 2) == 0 | `i' == 5,2, 1)
		local cond
		if `i' < 5 local cond "if thana <= 24" 
		local target
		local target : word `j' of  "mistarget_adj" "mistarget_adj participant" // "nontrgth" "nontrgth participant"
		if `i' >=  3 local target `target' t_2 - t_29 
		di "`target'"
		reg landb_adjunitval halab_adj  halabsq `target'  [weight = weight] `cond'
		eststo _`i'b
		local method = cond(`i' <= 2, "OLS", "thana fe")
		estadd local method "`method'"
		local domain = cond(`i' <= 4, "program", "all")
		estadd local domain "`domain'"
	}
}

reg landb_adjunitval halab_adj  halabsq mistarget_adj participant nontar t_2 - t_29 [weight = weight] 
eststo _6b
estadd local method "thana fe"
estadd local domain "all"
test nontar = mistarget_adj
estadd local test = r(p)

nestreg :reg  landb_adjunitval (halab_adj halabsq mistarget_adj  t_*) (participant) (nontar)  [weight = int(1000* weight)] if  thana <= 24 
eststo _7b
estadd local method "thana fe"
estadd local domain "all"
mat wald = r(wald)
estadd sca participant = wald[2,6] 
estadd sca nontar = wald[3,6] 

** appendix table 10 - replicates Pitt Table 3 & adds col 6
noisily esttab _*b  using  "${workingpath}\table10.csv", replace /// // pitt1999table3.csv
	keep(halab_adj mistarget_adj halabsq participant nontar _cons) ///
	stats(N r2 method domain test participant nontar, fmt(0 3 9 9 3 3 3 ))


* Table in text
cap prog drop tWp
program define tWp
	test  0.target`1'#1.participant = 1.target`1'#1.participant	// target within participants
	estadd sca tWp = r(p) 
	test  0.target`1'#0.participant = 1.target`1'#0.participant	// target within non-participants
	estadd sca tWnp = r(p) 
	test  1.target`1'#0.participant = 1.target`1'#1.participant // participants within target
	estadd sca pWt = r(p) 
	test  0.target`1'#0.participant = 0.target`1'#1.participant	// participants within non-target
	estadd sca pWnt= r(p) 
end



reg landb_adjunitval halab_adj  c.halab_adj#c.halab_adj i.target#i.participant  [weight = weight] if thana <= 24
eststo _1t
estadd local thanafe "n"
estadd local domain "program"
tWp 

reg landb_adjunitval halab_adj  c.halab_adj#c.halab_adj i.target#i.participant  [weight = weight]
eststo _2t
estadd local thanafe "n"
estadd local domain "all"
tWp 

reg landb_adjunitval halab_adj  c.halab_adj#c.halab_adj i.target#i.participant i.thana [weight = weight] if thana <= 24
eststo _3t
estadd local thanafe "y"
estadd local domain "program"
tWp 

reg landb_adjunitval halab_adj  c.halab_adj#c.halab_adj i.target#i.participant  i.thana [weight = weight]
eststo _4t
estadd local thanafe "y"
estadd local domain "all"
tWp

reg landb_adjunitval halab_adj  c.halab_adj#c.halab_adj i.target2#i.participant  [weight = weight] if thana <= 24 
eststo _5t
estadd local thanafe "n"
estadd local domain "program"
tWp 2

reg landb_adjunitval halab_adj  c.halab_adj#c.halab_adj i.target2#i.participant  [weight = weight] 
eststo _6t
estadd local thanafe "n"
estadd local domain "all"
tWp 2

reg landb_adjunitval halab_adj  c.halab_adj#c.halab_adj i.target2#i.participant i.thana [weight = weight] if thana <= 24
eststo _7t
estadd local thanafe "y"
estadd local domain "program"
tWp 2

reg landb_adjunitval halab_adj  c.halab_adj#c.halab_adj i.target2#i.participant i.thana [weight = weight]
eststo _8t
estadd local thanafe "y"
estadd local domain "all"
tWp 


***************************************************************************************
noisily esttab _*t using "${workingpath}\table6.csv",  replace  b(3) se(3) /// cells("b(fmt(2)) se(fmt(3))") ///
	long stats(N r2 thanafe domain tWp tWnp pWt pWnt , ///
	fmt(0 3 3 3 3 3 )  ///
	labels("Num. Obs." "R2" "thana fe" "domain" "target within participants" "target within non-participants" "participants within target" "participants within non-target")) ///
	drop(*.thanaid)
***************************************************************************************


***************************************************************************************
* figures 6-8                                                                         *
***************************************************************************************
* what is the nontrgth variable?
gen nontar0 = csg == 0
tab nontar0 nontrgth // eureka! 

* how do nontarget households differ from mis-targeted households?
gen totassets = totvalb_adj + nonlandasset
gen nontar_assets = totassets < 100000

*~(participant | (halab_adj < 50 | totassets < 100000)) // NOT(MF borroweer OR (less than 50d OR assets < value of 100d medium qual land))
gen ltotassets = ln(totassets)
gen ltotvalb = ln(totvalb_adj)
ttest totvalb_adj if mistarget_adj == 1 | nontrgth == 1, by(nontrgth)

***************************************************************************************
** figure 6
***************************************************************************************
gen lcultown = ln(CultivableLandOwned)
ttest lcultown if mistarget_adj == 1 | nontrgth == 1, by(nontrgth)

hist  lcultown if mistarget_adj == 1 , xtitle("log area of cultivable land owned") title("mis-target") name(misstarget2, replace)  nodraw
hist  lcultown if nontrgth == 1, xtitle("log area of cultivable land owned") title("non-target") name(nontrgth2, replace)  nodraw
gr combine misstarget2 nontrgth2, rows(2) imargin(zero) ///
	xcommon name(figure6, replace) ///
	 saving("${workingpath}\figure6.gph", replace) // title(Distributions of (log) Cultivable Land Owned) 


***************************************************************************************
** figure 7
***************************************************************************************
hist  ltotvalb if mistarget_adj == 1 , name(misstarget1, replace) xscale(log range(6.37 15.1)) ///
	xtitle("log value of cultivable land owned") title("mis-target") nodraw
hist  ltotvalb if  nontrgth == 1, name(nontrgth1, replace) xscale(log range(6.37 15.1))  ///
	xtitle("log value of cultivable land owned") title("non-target") nodraw
gr combine misstarget1 nontrgth1, rows(2)imargin(zero) ///
	xcommon name(figure7, replace) ///
	 saving("${workingpath}\figure7.gph", replace)


***************************************************************************************
** figure 8
***************************************************************************************
gen llandb_adjunitval = ln(landb_adjunitval )

ttest llandb_adjunitval if mistarget_adj == 1 | nontrgth == 1, by(nontrgth)
hist  llandb_adjunitval if mistarget_adj == 1 , ///
	xtitle("(log) unit value of land owned") title("mis-target") name(misstarget3, replace)  nodraw
hist  llandb_adjunitval if nontrgth == 1, ///
	xtitle("()log) unit value of land owned") title("non-target") name(nontrgth3, replace)  nodraw
gr combine misstarget3 nontrgth3, rows(2) imargin(zero) ///
	xcommon name(figure8, replace) ///
	 saving("${workingpath}\figure8.gph", replace) // title(Distributions of log) unit values Cultivable Land Owned) 



***************************************************************************************
** figure 9
***************************************************************************************
ttest ltotassets if mistarget_adj == 1 | nontrgth == 1, by(nontrgth)
hist  ltotassets if mistarget == 1 , name(misstarget4, replace) ///
	title("mistarget") xtitle("log of value of total assets") xscale(log range(8 15.1)) nodraw
hist  ltotassets if nontrgth == 1, name(nontrgth4, replace) ///
	title("nontarget") xtitle("log of value of total assets") xscale(log range(8 15.1)) nodraw
** figure 9
gr combine misstarget4 nontrgth4, rows(2) xcommon name(figure9, replace)  saving("${workingpath}\figure9.gph", replace)


***************************************************************************************
** figure 10
***************************************************************************************
* restrict sample to unit values < 5000 tk/decimal
wlowess ltotassets lhalab if tp_cata == 1 [pw=weight], xb(low_totassets_a1_xb) stdp(low_totassets_a1_stdp)
wlowess ltotassets lhalab if tp_cata == 2 [pw=weight], xb(low_totassets_a2_xb) stdp(low_totassets_a2_stdp)
wlowess ltotassets lhalab if tp_cata == 3 [pw=weight], xb(low_totassets_a3_xb) stdp(low_totassets_a3_stdp)
wlowess ltotassets lhalab if tp_cata == 4 [pw=weight], xb(low_totassets_a4_xb) stdp(low_totassets_a4_stdp)

forval i = 1/4 {
		gen low_totassets_a`i'_CIL = low_totassets_a`i'_xb - 1.96 * low_totassets_a`i'_stdp
		gen low_totassets_a`i'_CIU = low_totassets_a`i'_xb + 1.96 * low_totassets_a`i'_stdp
}

twoway rarea low_totassets_a1_CIU low_totassets_a1_CIL lhalab, fcolor(green) fintensity(inten30) astyle(ci) || ///
	rarea low_totassets_a2_CIU low_totassets_a2_CIL lhalab, fcolor(blue) fintensity(inten30) astyle(ci) || ///
	rarea low_totassets_a3_CIU low_totassets_a3_CIL lhalab, fcolor(red) fintensity(inten30) astyle(ci) || ///
	rarea low_totassets_a4_CIU low_totassets_a4_CIL lhalab, fcolor(yellow) fintensity(inten30) astyle(ci) || ///
	scatter ltotassets lhalab if landb_adjunitval < 5000 & tp_cata == 1, mcolor(green)  msize(vsmall) msymbol(circle..)  || /// // 
	scatter ltotassets lhalab if landb_adjunitval < 5000 & tp_cata == 2, mcolor(blue)  msize(vsmall) msymbol(circle..)  || /// // 
	scatter ltotassets lhalab if landb_adjunitval < 5000 & tp_cata == 3, mcolor(red)  msize(vsmall) msymbol(circle..)  || /// // 
	scatter ltotassets lhalab if landb_adjunitval < 5000 & tp_cata == 4, mcolor(yellow)  msize(vsmall) msymbol(circle..)  /// // 
	xline(`=ln(50)', lwidth(vvthin) lpattern(dash))  ///
	title("total value of assets by land owned before MF/at time of survey" , margin(medsmall) orient(horizontal) size(medium) span) scheme(s1color) ///
	plotregion(style(none) margin(zero)) ysize(4) xsize(6.5) ///
	ytitle("log tk") ///
	yscale(lpattern(blank)) xscale(range(0 2.060514)) xtitle("land owned (ln(decimals))") ///
	note("weighted lowess regression estimates", size(small)) ///
	legend(label(1 "target participant") label(2 "mis-target") label(3 "target non-participant") label(4 "non-nontrgth == 1") order(1 2 3 4)) ///
	name(figure10, replace) saving("${workingpath}\figure10.gph", replace)

***************************************************************************************

} // end quietly

* Figures 6-10 