* 1. replicate Pitt, 1999 tables
qui {
clear all

use "${datapath1}\ROSTERR1.DTA", clear
sort nh /*preparation for merging: nh is the identifying variable in both STATA files: 13AR1 and ROSTERR1 */
preserve
	use if halaid ~= 6 using "${datapath1}\13AR1.DTA", clear // all land
	label define halaid 1 "homestead land" 2 "pond/orchard/bamboo" 3 "Own cultivation" 4 "Sharecrop out" 5 "Own land other" 6 "total value of land"
	label val halaid 
	label var halaid "land types"
	levelsof halaid, local(levels)
	foreach v in `levels' {
		gen halab_`v' = halab if halaid == `v'
		gen halaa_`v' = halaa if halaid == `v'
	}
	collapse (sum) halab* halaa* , by(nh) // cultivable land
/*merge both data sets, be in 06AR1 STATA window:*/
	sort nh /*preparation for merging: nh is the identifying variable in both STATA files: 13AR1 and ROSTERR1*/
	tempfile t
	save `t'
restore
merge 1:1 nh using `t'
tab _merge
drop _m*
sort nh

* weights
merge nh using "${datapath1}\wght1.dta"
tab _merge
drop _m*

label define  progid 1 "BRAC" 2 "BRDB" 3 "Grameen Bank" ///
	4 "other - ineligible households/eligible but not participating" 5 "Non-participants/control group", modify
label val progid progid

foreach v in  halab halab_1 halab_2 halab_3 halab_4 halab_5 halaa halaa_1 halaa_2 halaa_3 halaa_4 halaa_5  {
	replace `v' = 0 if `v' == .
}

gen elig8 = halab < 50 
tab elig8 progid if progid <= 3, m

table elig8 progid, c(mean halab) f(%5.2f) row 

*** nearly Pitt 1999 table 1 upper 
gen halab_cult = halab_3 + halab_4
gen halaa_cult = halaa_3 + halaa_4

*table progid [weight = int(1000*weight)] if progid <= 3, c(mean halab_3 p50 halab_3 ) f(%5.2f) row 
table progid [weight = int(1000*weight)] if progid <= 3, c(mean halab_cult p50 halab_cult ) f(%5.2f) row 

*******************************************************************************************************
* Pitt 1999 table 1
*******************************************************************************************************
qui tabstat halab_cult [weight = int(1000*weight)] if progid <= 3, by(progid) s(n mean  p50  ) save
forval i = 1/3 {
	mat r`i' = r(Stat`i')
}
mat r4 = r(StatTotal)
tempvar n
gen `n' = halab_cult > 50
tab progid `n' if progid <= 3 , row col matrow(rows) matcell(cells) matcol(cols)
mat results1 = J(5, 4, .)
forval i = 1/3 {
	mat results1[1,`i'] = r`i'[2, 1]
	mat results1[2,`i'] = r`i'[3, 1]
	mat results1[3,`i'] = cells[`i', 2]
	mat results1[4,`i'] = 100 * cells[`i', 2] / (cells[`i', 1] + cells[`i', 2])
	mat results1[5,`i'] = r`i'[1, 1]
}
mat results1[1, 4] = r4[2,1]
mat results1[2, 4] = r4[3,1]
mat results1[3, 4] = cells[1, 2] + cells[2, 2] + cells[3, 2]
mat results1[4, 4] = 100 * results1[3, 4] / r4[1, 1]
mat results1[5, 4] = r4[1,1]

*************************************************
* Pitt 1999 table 1 panel a 
* appendix table 10
*************************************************
mat colnames results1 = brac brdb gb total
mat rownames results1 = mean median numgt50d pcgt50d total
mat list results1
esttab matrix(results1)



*************************************************
* table 1b
*************************************************
qui tabstat halab [weight = int(1000*weight)] if progid <= 3, by(progid) s(n mean  p50  ) save
forval i = 1/3 {
	mat r`i' = r(Stat`i')
}
mat r4 = r(StatTotal)
tempvar n
gen `n' = halab > 50
tab progid `n' if progid <= 3 , row col matrow(rows) matcell(cells) matcol(cols)
mat results2 = J(5, 4, .)
forval i = 1/3 {
	mat results2[1,`i'] = r`i'[2, 1]
	mat results2[2,`i'] = r`i'[3, 1]
	mat results2[3,`i'] = cells[`i', 2]
	mat results2[4,`i'] = 100 * cells[`i', 2] / (cells[`i', 1] + cells[`i', 2])
	mat results2[5,`i'] = r`i'[1, 1]
}
mat results2[1, 4] = r4[2,1]
mat results2[2, 4] = r4[3,1]
mat results2[3, 4] = cells[1, 2] + cells[2, 2] + cells[3,  2]
mat results2[4, 4] = 100 * results2[3, 4] / r4[1, 1]
mat results2[5, 4] = r4[1,1]
mat colnames results2 = BRAC BRDB GB Total



*****************************************************
* Pitt 1999 table 1 panel b
* appendix table 11
*****************************************************
mat colnames results2 = brac brdb gb total
mat rownames results2 = mean median numgt50d pcgt50d total
mat list results2

esttab matrix(results2)


*****************************************************
* Pitt 1999 table 2 panel a
*****************************************************
* get credit status - according to Pitt
preserve 
	use "${pittpath}\PKexp.dta", clear
	keep nh round creditf creditm
	keep if round == 1
	drop round
	sort nh 
	tempfile t
	save `t'
restore
sort nh 
merge 1:1 nh using `t'
tab _merge
keep if _merge == 3
drop _merge
gen participant = creditf > 0 | creditm > 0

qui tabstat halaa_cult [weight = int(1000*weight)] if progid <= 3 , by(progid) s(n mean  p50  ) save
forval i = 1/3 {
	mat r`i' = r(Stat`i')
}
mat r4 = r(StatTotal)
tempvar n
gen `n' = halaa_cult > 50
tab progid `n' if progid <= 3 , row col matrow(rows) matcell(cells) matcol(cols)
mat results3 = J(5, 4, .)
forval i = 1/3 {
	mat results3[1,`i'] = r`i'[2, 1]
	mat results3[2,`i'] = r`i'[3, 1]
	mat results3[3,`i'] = cells[`i', 2]
	mat results3[4,`i'] = 100 * cells[`i', 2] / (cells[`i', 1] + cells[`i', 2])
	mat results3[5,`i'] = r`i'[1, 1]
}
mat results3[1, 4] = r4[2,1]
mat results3[2, 4] = r4[3,1]
mat results3[3, 4] = cells[1, 2] + cells[2, 2] + cells[3, 2]
mat results3[4, 4] = 100 * results3[3, 4] / r4[1, 1]
mat results3[5, 4] = r4[1,1]

*****************************************************
* Pitt 1999 table 2 panel a
* appendix 11 panel a
*****************************************************
mat colnames results3 = brac brdb gb total
mat rownames results3 = mean median numgt50d pcgt50d total
mat list results3
esttab matrix(results3)


*****************************************************
* Pitt 1991 table 2b
*****************************************************
qui tabstat halaa [weight = int(1000*weight)] if progid <= 3, by(progid) s(n mean  p50  ) save
forval i = 1/3 {
	mat r`i' = r(Stat`i')
}
mat r4 = r(StatTotal)
tempvar n
gen `n' = halaa > 50
tab progid `n' if progid <= 3 , row col matrow(rows) matcell(cells) matcol(cols)
mat results4 = J(5, 4, .)
forval i = 1/3 {
	mat results4[1,`i'] = r`i'[2, 1]
	mat results4[2,`i'] = r`i'[3, 1]
	mat results4[3,`i'] = cells[`i', 2]
	mat results4[4,`i'] = 100 * cells[`i', 2] / (cells[`i', 1] + cells[`i', 2])
	mat results4[5,`i'] = r`i'[1, 1]
}
mat results4[1, 4] = r4[2,1]
mat results4[2, 4] = r4[3,1]
mat results4[3, 4] = cells[1, 2] + cells[2, 2] + cells[3,  2]
mat results4[4, 4] = 100 * results4[3, 4] / r4[1, 1]
mat results4[5, 4] = r4[1,1]

*****************************************************
* Pitt 1999 table 2 panel b
* appendix 11 panel b
*****************************************************
mat colnames results4 = brac brdb gb total
mat rownames results4 = mean median numgt50d pcgt50d total
mat list results4
esttab matrix(results4)


} // end quiet

mat results1234 = results1\results2\results3\results4
* Pitt 1999 Tables 1 & 2 (appendix table 10 & 11

esttab matrix(results1234) using "${workingpath}\tables8N9.csv", replace 

* Rows 1-8 are Table 10
* Rows 9-16 are Table 11
* Pitt's figures are in this .do file if you want to check our results

qui {

/*
* pitt's 1999 results
preserve
	drop _all
	input pop var stat brac brdb gb tot
	all cult mean 34.18 32.92 35.21 34.21
	all cult med 0 0 0 0
	all cult nolt50d 46 45 66 157
	all cult pclt50d 16.1 14.6 21.1 17.3
	all cult numhh 285 308 312 905
	all owned mean 47.08 44.3 52.01 48.01
	all owned med 10 10 16 11
	all owned nolt50 59 56 88 203
	all owned pclt50d 20.7 18.2 28.2 22.4
	all owned numhh 285 308 312 905
	part cult mean 41.5 35.93 42.01 40.32
	part cult med 0 0 4 0
	part cult nolt50d 50 51 74 179
	part cult pclt50d 17.5 16.6 23.7 19.8
	part cult numhh 285 308 312 905
	part owned mean 54.93 48.18 59.48 554.78
	part owned med 10 13 21 15
	part owned nolt50 67 66 94 227
	part owned pclt50d 23.5 21.4 30.1 25.1
	part owned numhh 285 308 312 905

	tempfile t 
	save `t', replace
*/

}

