*********************************************************************************
* Replicate Pitt's PSM   i.e. corresponding that reported in DJP5a.pdf table 2  *
* but mainly just Pitt's kernel_commontrim0.do file                             *
*********************************************************************************

qui {
do ${progpath}\mp_routines.do"

use "${pittpath}\PKexp", clear
sort nh round
replace loghland = ln(123) if nh == 32111	/* error in data for this household */

gen thana=int(vill/10)
xi i.thana, noomit
unab dummies: _Ithana*

* gen credit dummies
gen credit = creditf > 0 | creditm > 0
gen creditff : "household has female credit" = creditf > 0
gen creditmm : "household has male credit" = creditm > 0 // rpj

* Pitt's village has fe/male credit dummy 
* these variables are faulty because
* (a) _Wwvill_11 & _Mmvill_11 missing although there are male and female borrowwers in round 1
* (b) _Wwvil_143 is missing although it has 5 female borrowers in round 1
egen wvill=rowmax(_W*)
egen mvill=rowmax(_M*)

* rpj variables 
* credit in any round
gen fhh_ = creditff > 0
gen mhh_ = creditmm > 0
bys nh (round) : egen fhh = max(fhh_)
bys nh (round) : egen mhh = max(mhh_)
label var fhh "household has female credit - any round"
label var mhh "household has male credit - any round"

* some households get credit for first time in rounds 2 & 3 only
gen fhh1_ = creditff > 0 & round == 1	// household with female credit in round 1
gen mhh1_ = creditmm > 0 & round == 1	// household with male credit in round 1
bys nh : egen fhh1 = max(fhh1_)
bys nh : egen mhh1 = max(mhh1_)
gen fhh2_ = creditf > 0 & round >= 2 & fhh1 == 0	// households with female credit in rounds 2 & 3 but not round 1
gen mhh2_ = creditm > 0 & round >= 2 & mhh1 == 0	// households with male credit in rounds 2 & 3 but not round 1
bys nh : egen fhh2 = max(fhh2_)
bys nh : egen mhh2 = max(mhh2_)

label var fhh1 "household has female  credit in round1"
label var mhh1 "household has male  credit in round1"
label var fhh2 "household has female  credit first in rounds 2 or 3"
label var mhh2 "household has male  credit first in rounds 2 or 3"

tab vil if round == 1  & fhh2 == 1
* 28 households get loans in waves 2 & 3 which did not have tehm in round 1 

tab nh fhh2 if round == 1 & fhh2 == 1, matrow(row) matcell(cell)
mat list row
* get list of households which borrow for first time in rounds 2 or 3
local list
local r = rowsof(row)
forval i = 1/`r' {
	local nh = row[`i', 1]
	if `i' == 1 { 
		local list = "`nh', "
	}
	else if `i' < `r' {
		local list = "`list' `nh', "
	}
	else {
		local list = "`list' `nh'"
	}
*	di "`list'"
}
di "	`list'"
gen fborr_r2N3 : "household female borrower first rounds 2 or 3 " = inlist(nh, `list')



* villages with any female borrowing
* these variables do not correspond exactly to wvill or mvill defined by Pitt 
* because they include borrowin in rounds 2 & 3 as well as in those villages where _W* or _Mm* are missing
bys vill (nh round): egen f_vill = max(creditff)
bys vill (nh round): egen m_vill = max(creditmm)

* female credit prior to survey
bys vill (nh round): egen f_vill1 = max(fhh1)
bys vill (nh round): egen m_vill1 = max(mhh1)
* this is better, however, village 111 (3 female loans in 1990), 113 (2 female )

*
* include only 11 & 143 as others have too few loans
*

* eligible per village
gen choice = wchoice | mchoice	
/*  wchoice and mchoice correspond to borrowing in round 1 but excludes villages 143 & 242 */
tab vil round if wchoice ~= f_vill1 & nontrgth == 0

* households with choice but not wvill > 0    !
tab wchoice wvill if round == 1
* wchoice identifies 11, 142, but not 143, or 242.

table  vill round creditff  if wvill == 0 & f_vill == 1
* 3 villages have fcredit in round 1; more in rounds 2 & 3
* wchoice needs to reflect households which are eligible and have access to female MFI

* probably best to drop hh which get credit only in rounds 2 & 3 as cannot be affected by credit.
* although can consume credit immediately?

* have choice by non-target status
tab wchoice nontrgth if round == 1, m // if thana <= 24
/*
nontrgth is never derfined - initially we thought it would be defined by data 
e.g. "non-borrower" housheolds which are not eligible by 0.5 acres rule
this is not the case. 
Later (after lot of effort) it turned out that it was defined by csg in data file 11cr[r]
*/

* eiligibility based on choice
by vill (nh round), sort : egen eligdefacto = total(choice) if round == 1 & choice == 1
by vill (nh round), sort : egen noneligdefacto = total(choice) if round == 1 & choice == 0
bys vill (nh round) : egen numhh = count(nh) if round == 1
tab  numhh eligdefacto if round == 1 & thana <= 24 // no villages have more than three eligible non-borrowing households

* creditff included households with new borrowing in rounds 2 & 3
table vill creditff fhh1  if creditff ~= fhh1

tempvar t1 t2
bys vill (nh round) : egen t1 = count(nh) if round == 1 & choice == 1 & credit == 0
bys vill (nh round): egen elignoncredit = max(t1)
bys vill (nh round) : egen t2 = count(nh) if round == 1 & credit == 1
bys vill (nh round): egen  hhborrowers = max(t2)


set seed 50581123
gen gg=uniform()
sort gg


*********************************************************************************
* Table 1 
*********************************************************************************
mat results1 = J(20, 8, .)
mat colnames results1 = number diff sediff pdif tdiff cilo cihi
* rows are author, sample, prediction, 
* mat rownames results = mc_tr_e mc_tr_ee mc_c_e mc_c_ee dpj_tr_e dpj_tr_ee dpj_c_e dpj_c_ee mc_tr_e_np mc_tr_ee_np dpj_tr_e_np dpj_tr_ee_np

* first bybandwidth

** replicates MP - 
* kernel
psmatch2 creditff trlnd23 trlnd22 trlnd21 trlnd13 trlnd12 trlnd11 /// 
             loghland educhead sexhead agehead maxeducf maxeducm  ///
             noadultm nospouse noadultf  _W*  round2 round3 nontrgth ///   
             if thana <= 24 & wvill ~= 0, ///
             	out(lexptot) kernel bwidth(.08) logit  common  // quietly            	
store 1 results1 		// table 1 row 1
* very low pseudo r2
* but nontrgth drops 438 obs and noadultf drops 53
* the nontrght == 1 hh should not be relevant - ? kernel estimation
* there are male borrower households in both treated and untreated households in the estimation sample.
tab creditmm _treated if e(sample)	// includes male credit households
tab fhh2 _treat if e(sample)	// includes households which get credit for first time in rounds 2 & 3 in treated and control

psgraph
* balancing
pstest trlnd23 trlnd22 trlnd21 trlnd13 trlnd12 trlnd11 /// 
             loghland educhead sexhead agehead maxeducf maxeducm  ///
             noadultm nospouse, graph both name(_mp_psm, replace) title(village fixed effects) 
/*
* additional balancing tests
qqgraph trlnd23 trlnd22 trlnd21 trlnd13 trlnd12 trlnd11 /// 
             loghland educhead sexhead agehead maxeducf maxeducm  ///
             noadultm nospouse noadultf, treatment(_treated) weight(_weight) precision(10) name("_1", replace)

qqcompare_rpj trlnd23 trlnd22 trlnd21 trlnd13 trlnd12 trlnd11 /// 
             loghland educhead agehead maxeducf maxeducm  ///
              , treatment(_treated) weight(_weight) precision(10)

catcompare sexhead ///
             noadultm nospouse noadultf nontrgth, treatment(_treated) weight(_weight) precision(0.01)
*/


* now use borrowers in round 1 (fhh1) and  exclude borrowers from Rounds 2 & 3
psmatch2 fhh1 trlnd23 trlnd22 trlnd21 trlnd13 trlnd12 trlnd11 /// 
             loghland educhead sexhead agehead maxeducf maxeducm  ///
             noadultm nospouse noadultf  _W*  round2 round3 nontrgth /// //  
             if thana <= 24 & wvill ~= 0, ///
             	out(lexptot) kernel bwidth(.08) logit  common  quietly            	
store 2 results1 		// not reported
tab creditmm _treated if e(sample)	// shows that male borrowing households are included
tab fhh2 _treat if e(sample)	// includes households which get credit for first time in rounds 2 & 3 in untreated only

* drop  ouseholds which borrow in rounds 2 or 3 for first time (fhh2)
psmatch2 fhh1 trlnd23 trlnd22 trlnd21 trlnd13 trlnd12 trlnd11 /// 
             loghland educhead sexhead agehead maxeducf maxeducm  ///
             noadultm nospouse noadultf  _W*  round2 round3 nontrgth /// //  
             if thana <= 24 & wvill ~= 0 & fhh2 == 0 , ///
             	out(lexptot) kernel bwidth(.08) logit  common  quietly            	
* virtually no difference - discard 

* add additional with female credit dummy for village 11 and 143
gen _Wwvill_11 = vill == 11 
replace wchoice = 1 if vill == 11 & nontrgth == 0	// wchoice for vill 11 is correct
gen _Wwvill_143 = vill == 143 
replace wchoice = 1 if vill == 143 & nontrgth == 0	// "corrects" wchoice for non non-target households in Village 143

* creditff use all villages with wchoice exclude male borrowing households (any round)
psmatch2 creditff trlnd23 trlnd22 trlnd21 trlnd13 trlnd12 trlnd11 /// 
             loghland educhead sexhead agehead maxeducf maxeducm  ///
             noadultm nospouse noadultf nontrgth _W* round2 round3  /// 
             if thana <= 24 & wchoice == 1 & mhh == 0 /// 
             , out(lexptot) kernel bwidth(.08) logit  common // quietly
store 3 results1		// table 1 row 2
* now there are NO male borrower households in either treated or untreated households in the estimation sample.
tab creditmm _treated if e(sample)
tab fhh2 _treat if e(sample)	// includes households which get credit for first time in rounds 2 & 3 in untreated only

* drop fhh2 househlds - households which borrow in rounds 2 or 3
psmatch2 creditff trlnd23 trlnd22 trlnd21 trlnd13 trlnd12 trlnd11 /// 
             loghland educhead sexhead agehead maxeducf maxeducm  ///
             noadultm nospouse noadultf nontrgth _W* round2 round3  ///   
             if thana <= 24 & wchoice == 1 & mhh == 0 & fhh2 == 0 ///
             , out(lexptot) kernel bwidth(.08) logit  common quietly
* again virtually no difference


* fhh1 use all villages with wchoice exclude male borrowing households (any round)
psmatch2 fhh1 trlnd23 trlnd22 trlnd21 trlnd13 trlnd12 trlnd11 /// 
             loghland educhead sexhead agehead maxeducf maxeducm  ///
             noadultm nospouse noadultf nontrgth _W* round2 round3  ///   
             if thana <= 24 & wchoice == 1 & mhh == 0 /// 
             , out(lexptot) kernel bwidth(.08) logit  common quietly
store 4 results1
* now there are NO male borrower households in either treated or untreated households in the estimation sample.
tab creditmm _treated if e(sample)

* drop fhh2 = 1 households
psmatch2 fhh1 trlnd23 trlnd22 trlnd21 trlnd13 trlnd12 trlnd11 /// 
             loghland educhead sexhead agehead maxeducf maxeducm  ///
             noadultm nospouse noadultf nontrgth _W* round2 round3  /// //  
             if thana <= 24 & wchoice == 1 & mhh == 0 & fhh2 == 0  /// 
             , out(lexptot) kernel bwidth(.08) logit  common quietly
store 5 results1

* balancing - not reported
pstest trlnd23 trlnd22 trlnd21 trlnd13 trlnd12 trlnd11 /// 
             loghland educhead sexhead agehead maxeducf maxeducm  ///
             noadultm nospouse, graph both name(_mp_alt_psm, replace) title(village covariates)  

****************************************************
* Figure 1 - 
****************************************************
graph combine _mp_psm  _mp_alt_psm, rows(2) xsize(7.6) ysize(11.5) ///
	name(figure1, replace) ///
	saving("${workingpath}\figure1.gph", replace)

mat list results1


*************************************************************************************
*Nearest Neighbour & Sensitivity Analysis
* table 1 Panel 2
*************************************************************************************
* creditff
* Replicates MP -  nearest neighbour excludes male borrowing households (any round)
psmatch2 creditff trlnd23 trlnd22 trlnd21 trlnd13 trlnd12 trlnd11 /// 
             loghland educhead sexhead agehead maxeducf maxeducm  ///
             noadultm nospouse noadultf  _W*  round2 round3 nontrgth /// //  
             if thana <= 24 & wchoice == 1 & mhh == 0 , ///
             	out(lexptot) n(10) logit  common  quietly
store 6 results1	// Table 1 row 3
rsens_rpj lexptot, gamma(1(.05)2)	/*  ns at gamma = 1.25 (10%) */
mat rsensvalues = r(rsensvalues)
* get results or rsens
sa_results 6 rsensvalues results1

* fhh1
psmatch2 fhh1 trlnd23 trlnd22 trlnd21 trlnd13 trlnd12 trlnd11 /// 
             loghland educhead sexhead agehead maxeducf maxeducm  ///
             noadultm nospouse noadultf  _W*  round2 round3 nontrgth /// //  
             if thana <= 24 & wchoice == 1 & mhh == 0 , ///
             	out(lexptot) n(10) logit  common  quietly
store 7 results1
rsens_rpj lexptot, gamma(1(.05)2)	/*  ns at gamma = 1.3 (10%) */
mat rsensvalues = r(rsensvalues)
* get results or rsens
sa_results 7 rsensvalues results1


/*
qqgraph educhead, treatment(_treated) weight(_weight) precision(100) name(_1a)

cquantile educhead if thana <= 24  & wvill ~= 0 & noadultf ~= 1 & nontrgth ~= 1, by(creditff) gen(t_1 t_2)
qqplot t_1 t_2, title(before) name(before, replace)

cquantile educhead if thana <= 24  & wvill ~= 0 & noadultf ~= 1 & nontrgth ~= 1 & _weight ~= . & _support == 1, by(_treated) gen(t_1a t_2a)
qqplot t_1a t_2a, title(after) name(after, replace)

graph combine before after, rows(2) xsize(7.6) ysize(10.7) xcommon ycommon

cquantile lexptot if thana <= 24  & wvill ~= 0 & noadultf ~= 1 & nontrgth ~= 1, by(creditff) gen(t_1 t_2)
qqplot t_1 t_2, name(before, replace)

cquantile lexptot if thana <= 24  & wvill ~= 0 & noadultf ~= 1 & nontrgth ~= 1, by(_treated) gen(t_1a t_2a)
qqplot t_1a t_2a, name(after, replace)
*/

* creditff
* nearest neightbour 1 - excluding male borrowing households 
psmatch2 creditff trlnd23 trlnd22 trlnd21 trlnd13 trlnd12 trlnd11 /// 
             loghland educhead sexhead agehead maxeducf maxeducm  ///
             noadultm nospouse noadultf  _W*  round2 round3 nontrgth /// //  
             if thana <= 24 & wchoice == 1 & mhh == 0, ///
             	out(lexptot) n(1) logit  common quietly       	
store 8 results1	// table 1 row 4
tempvar delta
gen `delta' = lexptot - _lexptot if _treat == 1 & _support == 1
rbounds `delta', gamma(1(.05)2)	/* not significant at gamma = 1.15 (10%) */
mat outmat = r(outmat)
* rbounds results
sa_results 8 outmat results1

* fhh1
psmatch2 fhh1 trlnd23 trlnd22 trlnd21 trlnd13 trlnd12 trlnd11 /// 
             loghland educhead sexhead agehead maxeducf maxeducm  ///
             noadultm nospouse noadultf  _W*  round2 round3 nontrgth /// //  
             if thana <= 24 & wchoice == 1 & mhh == 0, ///
             	out(lexptot) n(1) logit  common quietly       	
store 9 results1
tempvar delta
gen `delta' = lexptot - _lexptot if _treat == 1 & _support == 1
rbounds `delta', gamma(1(.05)2)	/* not significant at gamma = 1.15 (10%) */
mat outmat = r(outmat)

* rbounds results
sa_results 9 outmat results1


} // end quietly


**********************************************************************************************
* results in Rejoinder to Pitt Table 1
**********************************************************************************************
mat list results1
* matrix	table 
* row		row    
* Panel A - Replication of Pitt and excluding male borrowing households
* 1		1	replication of Pitt
* 3		2	excluding male hh
* panel B - Sensitivity Analysis
* 6		3	n(10)
* 8		4	n(1)

esttab matrix(results1, fmt(0 4 4 4 4 2 4 4)) using "${workingpath}\table1.csv", replace

*****************************************************************************************
* Table 1 is saved as "${workingpath}\table1.csv" - see rows for translation to Table 1 *
*****************************************************************************************
* Figure 1 is saved as "${workingpath}\figure1.grh" and as memory graph "figure1"       *
*****************************************************************************************


