*************************************************************************************
* Alternative target criteria
*************************************************************************************

* PSM with alternative non-target variables

qui {
clear all

do "${progpath}\mp_routines.do"
use "${pittpath}\PKexp", clear
sort nh round

replace loghland = ln(123) if nh == 32111	/* error in data for this household */

gen _Wwvill_11 = vill == 11 				// _Wwvill_11 is missing. Takes the value 1 for vill == 11
gen _Wwvill_143 = vill == 143 				// _Wwvill_143 is missing
replace wchoice = 1 if vill == 143 & nontrgth == 0	// vill 1343 clearly has wchoice == 1

gen thana=int(vill/10)
xi i.thana, noomit
unab dummies: _Ithana*
gen credit = creditf > 0 | creditm > 0
gen creditff = creditf > 0
gen creditmm = creditm > 0 // rpj

egen wvill=rowmax(_W*)
egen mvill=rowmax(_M*)

egen wvill_rpj = rowmax(_W*)	// has female village dumy

* credit in any round
gen fhh_ = creditff > 0
gen mhh_ = creditmm > 0
bys nh (round) : egen fhh = max(fhh_)
bys nh (round) : egen mhh = max(mhh_)
label var fhh "household has female credit - any round"
label var mhh "household has male credit - any round"

* some households get credit for first time in rounds 2 & 3 only
gen fhh1_ = creditff > 0 & round == 1	// household with female credit in round 1
gen mhh1_ = creditmm > 0 & round == 1	// household with male credit in round 1
bys nh : egen fhh1 = max(fhh1_)
bys nh : egen mhh1 = max(mhh1_)
gen fhh2_ = creditf > 0 & round >= 2 & fhh1 == 0	// households with female credit in rounds 2 & 3 but not round 1
gen mhh2_ = creditm > 0 & round >= 2 & mhh1 == 0	// households with male credit in rounds 2 & 3 but not round 1
bys nh : egen fhh2 = max(fhh2_)
bys nh : egen mhh2 = max(mhh2_)

label var fhh1 "household has female  credit in round1"
label var mhh1 "household has male  credit in round1"
label var fhh2 "household has female  credit first in rounds 2 or 3"
label var mhh2 "household has male  credit first in rounds 2 or 3"

tab vil if fhh2 == 1
tab vil if round == 1  & fhh2 == 1
* 28 households get loans for first time in waves 2 & 3 

tab nh fhh2 if round == 1 & fhh2 == 1, matrow(row) matcell(cell)
mat list row
* get list of households which borrow for first time in rounds 2 or 3
local list
local r = rowsof(row)
forval i = 1/`r' {
	local nh = row[`i', 1]
	if `i' == 1 { 
		local list = "`nh', "
	}
	else if `i' < `r' {
		local list = "`list' `nh', "
	}
	else {
		local list = "`list' `nh'"
	}
*	di "`list'"
}
di "	`list'"
gen fborr_r2N3 : "household female borrower first rounds 2 or 3 " = inlist(nh, `list')


* villages with any female borrowing
bys vill (nh round): egen f_vill = max(creditff)
bys vill (nh round): egen m_vill = max(creditmm)

* female credit prior to survey
bys vill (nh round): egen f_vill1 = max(fhh1)
bys vill (nh round): egen m_vill1 = max(mhh1)
* this is better, however, village 111 (3 female loans in 1990), 113 (2 female )

**************************************************************
* need to include only 11 & 143 as others have too few loans
**************************************************************

* eligible per village
gen choice = wchoice | mchoice	
/*  wchoice and mchoice correspond to borrowing in round 1 but excludes villages 143 & 242 */
tab vil round if wchoice ~= f_vill1 & nontrgth == 0

* households with choice but not wvill > 0    !
tab wchoice wvill if round == 1
* wchoice identifies 11, 142, but not 143, or 242.

table  vill round creditff  if wvill == 0 & f_vill == 1
* 3 vill have fcredit in round 1; more in rounds 2 & 3

* probably best to drop hh which get credit only in rounds 2 & 3 as cannot be affected by credit.although can consume credit

* have choice  by non-target status
tab wchoice nontrgth if round == 1, m // if thana <= 24

* eiligibility based on choice
by vill (nh round), sort : egen eligdefacto = total(choice) if round == 1 & choice == 1
by vill (nh round), sort : egen noneligdefacto = total(choice) if round == 1 & choice == 0
bys vill (nh round) : egen numhh = count(nh) if round == 1
tab  numhh eligdefacto if round == 1 & thana <= 24 // no villages have more than three eligible non-borrowing households

* creditff included households with new borrowing in rounds 2 & 3
table vill creditff fhh1  if creditff ~= fhh1

* run to ** as block
tempvar t1 t2
bys vill (nh round) : egen t1 = count(nh) if round == 1 & choice == 1 & credit == 0
bys vill (nh round): egen elignoncredit = max(t1)
bys vill (nh round) : egen t2 = count(nh) if round == 1 & credit == 1
bys vill (nh round): egen  hhborrowers = max(t2)
**


***********************************************************************************
* now use village covariates instead of village fixed effects
***********************************************************************************

* get village covariates
preserve
	use "${villvarspath}\village.dta", clear
	gen vill = upzid * 10 + villid
	ren wave round
	sort vill round
	tempfile t
	save `t',replace
restore
sort vill round

merge m:1 vill round using `t'
tab _merge
drop _merge

* pitt vars excluding village fixed effects (_W*)
* include round dummies
global pittvars "trlnd23 trlnd22 trlnd21 trlnd13 trlnd12 trlnd11 loghland educhead sexhead agehead maxeducf maxeducm  noadultm   noadultf nospouse nontrgth round2 round3 " //
* exclude round dummies
global pittvars1 "trlnd23 trlnd22 trlnd21 trlnd13 trlnd12 trlnd11 loghland educhead sexhead agehead maxeducf maxeducm  noadultm noadultf nospouse nontrgth"
* drop nontrgth & noadultf
global pittvars2 "trlnd23 trlnd22 trlnd21 trlnd13 trlnd12 trlnd11 loghland educhead sexhead agehead maxeducf maxeducm  noadultm nospouse round2 round3 "

global rpjvars1 "trlnd23 trlnd22 trlnd21 trlnd13 trlnd12 trlnd11 loghland educhead sexhead agehead maxeducf maxeducm  noadultm    nospouse  round2 round3 " // noadultf

global villvars "devprg primcoed junrcoed highcoed highgirl highboys postsec schmohal ilmi hpruralh hpmatern hpfampln hpmidwif puccac bankc shopc hdqrc fprg velec pzrice pzwflour pzsugar pzsoil pzmoil pzhegg pzmilk pzonion pzgarlic pzturmer pzpotato pzgrnpep pzsalt pzbeef pzchick pzbsugar wagem wagef wagec"
global villvars1 "bankc fprg hdqrc highboys highcoed highgirl hpfampln hpmidwif hpruralh junrcoed hpmatern hpmidwif postsec puccac pzchick pzhegg pzmoil pzturmer shopc wagec"
* droppostsec
global villvars2 "bankc fprg hdqrc highboys highcoed highgirl hpfampln hpmidwif hpruralh junrcoed hpmatern hpmidwif puccac pzchick pzhegg pzmoil pzturmer shopc wagec"


set seed 50581123
gen gg=uniform()
sort gg

* USE VALUE OF LAND OWNED AS NON_TAGET DEFINITION
* now add alternative land values to define alternative nontarget and land unit values
preserve
	use "${workingpath}\land_values.dta", clear
	sort nh
	tempfile t
	save `t'
restore
sort nh 
merge m:1 nh using `t'
tab _merge
keep if _merge == 3 	// drop households with >5 acres - even though some treated have > 5 acres - not in PKexp.
drop _merge

/*
* change land values
gen OwnedCultivated = halab_
gen loghOwnedCultivated = ln(OwnedCultivated + 0.1)
gen loghTotOwned = ln(TotOwned + 0.1)

*/
* add non landed assets

preserve
	use "${workingpath}\OutcomeVar_NonLandAssets_hh.dta", clear
	keep nh wave nonlandasset nonlandwomen lnnonlandwomen nonlandmen lnnonlandmen cssv cssgfv equipment transport other 
	ren wave round
	sort nh round
	tempfile t 
	save `t', replace
restore
sort nh round
merge 1:1 nh round using `t'
tab _merge
keep if _merge == 3
drop _merge

gen hland = exp(loghland)

gen totassets = totvalb_adj + nonlandasset	// totvalb ignores land values for non-participants 
gen nontar1 = credit == 0 & (halab_3 + halab_4 > 50) 				// cultivable land > 50 decimals
gen nontar_1 = creditf == 0 & creditm == 0 &  totvalb_adj > 50000 	// non-borrower & value of land > value of 0.5 acres (50000)  
gen nontar_4 = ~(credit | (hland > 50 | totassets >= 100000)) // NOT(MF borroweer OR (less than 50d OR assets < value of 100d medium qual land))
gen totassets2 = fltv + nonlandasset
gen nontar_5 = ~(credit | (hland < 50 | totassets2 < 100000)) // NOT(less than 50d OR assets < value of 100d medium qual land)
gen nontar_6 = creditf == 0 & creditm == 0  & ~(hland < 50 | totassets2 < 100000) // not bnorrower & NOT(less than 50d OR assets < value of 100d medium qual land)

save "${workingpath}\temp.dta", replace

use "${workingpath}\temp.dta", clear

* Chemin method 
* logits 
* without nontarget
/*
logit creditff trlnd23 trlnd22 trlnd21 trlnd13 trlnd12 trlnd11 /// 
             loghland educhead sexhead agehead maxeducf maxeducm  ///
             noadultm nospouse  _W* round2 round3 if wchoice == 1 & thana <= 24 & mhh == 0 // nontar1 noadultf nontrgth

* with nontrgth
logit creditff trlnd23 trlnd22 trlnd21 trlnd13 trlnd12 trlnd11 /// 
             loghland educhead sexhead agehead maxeducf maxeducm  ///
             noadultm nospouse noadultf nontrgth _W* round2 round3 if wchoice == 1 & thana <= 24 // & mhh == 0 // nontar1  nontrgth

* pitt specification
logit creditff trlnd23 trlnd22 trlnd21 trlnd13 trlnd12 trlnd11 /// 
             loghland educhead sexhead agehead maxeducf maxeducm  ///
             noadultm nospouse noadultf  _W*  round2 round3 nontrgth /// //  
             if thana <= 24 & wvill ~= 0,
*/
* logit with MP vars except noadultf & nontrgth
qui logit creditff trlnd23 trlnd22 trlnd21 trlnd13 trlnd12 trlnd11 /// 
             loghland educhead sexhead agehead maxeducf maxeducm  ///
             noadultm nospouse nontar1 _W* round2 round3 ///
             if wchoice == 1 & thana <= 24 & mhh == 0 [pweight = weight] // noadultf nontrgth
predict ps3 if e(sample)
* set _Ww... village dummies to zero
gen esample = e(sample)
tempvar esample
gen `esample' = e(sample)
tab vill `esample'
tab _Wwvill_112 `esample', m

tempvar esample
gen `esample' = e(sample)
tab _Wwvill_112 `esample'
levelsof vill if `esample', local(village)
foreach i in `village' {		
	tempvar _`i'
	cap drop _`i'
	gen _`i' = _Wwvill_`i'
	capture replace _Wwvill_`i' = 0 		// if _Wwvill_`i' ~=.
}
* predict propensity score without fillage fixed effects - all villages
predict ps3a
foreach i in `village' {		// replace recoded village dummies with original values
	cap replace _Wwvill_`i' = _`i' 
}

reg lexptot ibn.vill if (wchoice == 1 & thana <= 24 & creditmm == 0 & nontrgth == 0) | (nontrgth == 0 & thana >= 25) , nocons // `esample' 
predict e_lexptot, residuals


*********************************************************************************************
* Table 7                                                                                   *  
*********************************************************************************************
mat results2 = J(20, 8, .)
mat colnames results2 = number diff sediff pdif tdiff cilo cihi

* all villages village fixed effects 
* kernel
psmatch2 creditff if creditmm == 0 & thana <= 24, pscore(ps3) out(lexptot) kernel bwidth(.08) common
* table 7 row 1
local row = 1
eststo _`row'
*store 1 results2a 
estadd local treatvar "creditff"
estadd local domain "treatment"
estadd local matching "kernel"
estadd local nontar "nontrgth"
estadd local villfe "y"
estadd local villcov "n"
store `row' results2

* n(10) 
psmatch2 creditff if creditmm == 0 & thana <= 24, pscore(ps3) out(lexptot) n(10) common
* table 7 row 2
local row = 2
eststo _`row'
*store 1 results2a 
estadd local treatvar "creditff"
estadd local domain "treatment"
estadd local matching "kernel"
estadd local nontar "nontrgth"
estadd local villfe "y"
estadd local villcov "n"
store `row' results2
rsens_rpj lexptot, gamma(1(.05)2) nn(10)
mat rsensvalues = r(rsensvalues)
sa_results `row' rsensvalues results2

/*
* fhh1
psmatch2 fhh1 if creditmm == 0 & thana <= 24, pscore(ps3) out(lexptot) kernel bwidth(.08) common
local row = 2
eststo _`row'
estadd local treatvar "fhh1"
estadd local domain "treatment"
estadd local matching "kernel"
estadd local nontar "nontrgth"
estadd local villfe "y"
estadd local villcov "n"
store `row' results2
*/
* Chemin's estimation using control villages
psmatch2 creditff if (creditff == 1 & creditmm == 0) | thana > 24, pscore(ps3a) out(e_lexptot) kernel bwidth(.08) common
* table 7 row 3
local row = 3
eststo _`row'
estadd local treatvar "creditff"
estadd local domain "control"
estadd local matching "kernel"
estadd local nontar "nontrgth"
estadd local villfe "y"
estadd local villcov "n"
store `row' results2

* pittvars
* village covariates
psmatch2 creditff $pittvars $villvars2 if creditmm == 0, out(lexptot) kernel bw(0.08) common 
local row = 4
eststo _`row'
estadd local treatvar "creditff"
estadd local domain "all"
estadd local matching "kernel"
estadd local nontar "nontrgth"
estadd local villfe "n"
estadd local villcov "y"
store `row' results2


*n10
* pittvars
* village covariates
* nontrgth
psmatch2 creditff $pittvars $villvars2 if creditmm == 0, out(lexptot) n(10) common 
local row = 5
eststo _`row'
estadd local treatvar "creditff"
estadd local domain "all"
estadd local matching "nn10"
estadd local nontar "nontrgth"
estadd local villfe "n"
estadd local villcov "y"
store `row' results2
rsens_rpj lexptot, gamma(1(.05)2) nn(10)
mat rsensvalues = r(rsensvalues)
sa_results `row' rsensvalues results2

* rpjvars
* kernel
* village covariates
psmatch2 creditff $rpjvars1 $villvars2 if creditmm == 0, out(lexptot) kernel bw(0.08) common 
local row = 6
eststo _`row'
estadd local treatvar "creditff"
estadd local domain "all"
estadd local matching "kernel"
estadd local nontar "none"
estadd local villfe "n"
estadd local villcov "y"
store `row' results2

* test weight on no-target vs target househlds which are matched
tabstat _weight if (creditff == 0 & halab_adj < 50 ) | nontrgth == 1, by(nontrgth) s(n mean p50 p10 p90)
* mean weight heigher 
hist  _weight if (creditff == 0 & halab_adj < 50 ) | nontrgth == 1, by(nontrgth, rows(2))

tw hist _weight if (creditff == 0 & halab_adj < 50) , title("target non-participant") name(_1, replace)  nodraw
tw hist _weight if nontrgth == 1, title("non-target") name(_2, replace) nodraw
gr combine _1 _2, rows(2) xcommon xsize(7.6) ysize(10.7)

* rpjvars
* village covariates
* no nontarget
psmatch2 creditff $rpjvars1 $villvars2  if creditmm == 0, out(lexptot) n(10) common 
local row = 7
eststo _`row'
store `row' results2
estadd local treatvar "creditff"
estadd local domain "all"
estadd local matching "nn10"
estadd local nontar "nontar1"
estadd local villfe "n"
estadd local villcov "y"
rsens_rpj lexptot, gamma(1(.05)2) nn(10)
mat rsensvalues = r(rsensvalues)
sa_results `row' rsensvalues results2

save "${workingpath}\temp1.dta", replace


* rpjvars
* kernel
* village covariates
* nontar1
psmatch2 creditff $rpjvars1 $villvars2 nontar1 if creditmm == 0, out(lexptot) kernel bw(0.08) common 
local row = 8
eststo _`row'
store `row' results2
estadd local treatvar "creditff"
estadd local domain "all"
estadd local matching "kernel"
estadd local nontar "nontari"
estadd local villfe "n"
estadd local villcov "y"

* rpjvars
* village covariates
* nontar1
psmatch2 creditff $rpjvars1 $villvars2 nontar1 if creditmm == 0, out(lexptot) n(10) common 
local row = 9
eststo _`row'
store `row' results2
estadd local treatvar "creditff"
estadd local domain "all"
estadd local matching "nn10"
estadd local nontar "1"
estadd local villfe "n"
estadd local villcov "y"
rsens_rpj lexptot, gamma(1(.05)2) nn(10)
mat rsensvalues = r(rsensvalues)
sa_results `row' rsensvalues results2

mat rownames results2 = "MP" "creditff drop nontrgth" "fhh1 drop nontrgth" "creditff n10" "fhh1 n10" "creditff n1" "fhh1 n1"


gen nontar2 = credit == 0 &  totvalb_adj > 50000 	// non-borrower & value of land > value of 0.5 acres (50000)  
gen nontar3 = credit == 0 & totassets >= 100000 // 
gen nontar4 = credit == 0 & totassets >= 150000 // 
*/
*n10

* rpjvars
* village covariates

* rpjvars
* kernel
* village covariates
* nontar4
psmatch2 creditff $rpjvars1 $villvars2 nontar4 if creditmm == 0, out(lexptot) kernel bw(0.08) common 
local row = 10
eststo _`row'
store `row' results2
estadd local treatvar "creditff"
estadd local domain "all"
estadd local matching "kernel"
estadd local nontar "4"
estadd local villfe "n"
estadd local villcov "y"

* n(10)
psmatch2 creditff $rpjvars1 $villvars2 nontar4 if creditmm == 0, out(lexptot) n(10) common 
local row = 11
eststo _`row'
store `row' results2
estadd local treatvar "creditff"
estadd local domain "all"
estadd local matching "nn10"
estadd local nontar "4"
estadd local villfe "n"
estadd local villcov "y"
rsens_rpj lexptot, gamma(1(.05)2) nn(10)
mat rsensvalues = r(rsensvalues)
sa_results `row' rsensvalues results2

* drop mis-target
* nontar1
* n(10)
psmatch2 creditff $rpjvars1 $villvars2 nontar1 if creditmm == 0 & halab_adj < 50, out(lexptot) n(10) common 
local row = 12
eststo _`row'
store `row' results2
estadd local treatvar "creditff"
estadd local domain "all"
estadd local matching "nn10"
estadd local nontar "4"
estadd local villfe "n"
estadd local villcov "y"
rsens_rpj lexptot, gamma(1(.05)2) nn(10)
mat rsensvalues = r(rsensvalues)
sa_results `row' rsensvalues results2

} // end qui
*************************************************************************************************
** table 7 
*************************************************************************************************
*stats correspond to cols 2-7
esttab _1 _2 _3 _4 _5 _6 _7 _8 _9 _10 _11 _12, stats(N depvar treatvar domain matching nontar villfe villcov) 
mat colnames results2 = n diff sediff pdiff tdiff gamma siglo sighi
* mat rownames results2 = "MP" "creditff drop nontrgth" "Chemin control vills" "fhh1 drop nontrgth" "creditff n10" "fhh1 n10" "creditff n1" "fhh1 n1"
esttab matrix(results2, fmt(0 4 4 4 4 2 2)) using "${workingpath\}\table7.csv", replace
* drop rows 2, 4, & 6

* copy the last two outputs to excel and combine tables by hand 

* mat list results2 , f(%7.4f)


