******************************************************************************************
* suppose we use Chemin's approach for control villages withh Pitt household level data 
* Table 2, 3 & 4 & figure 1
* Tables 2-4 are displayed at the end of this file.
******************************************************************************************

qui {

clear all
**********************************************************
* load routines
**********************************************************
do ${progpath}\mp_routines.do"

**********************************************************
* prepare PKexp
**********************************************************

estimates clear

do ${progpath}\prepare_PKexp.do"

* get _W* dummies in order
qui des _W*, varlist
order nh-vill `r(varlist)'

* 
* logit with MP vars 
*
logit creditff trlnd23 trlnd22 trlnd21 trlnd13 trlnd12 trlnd11 /// 
             loghland educhead sexhead agehead maxeducf maxeducm  ///
             noadultm nospouse _W* round2 round3 nontrgth noadultf ///
             if wchoice == 1 & thana <= 24 & creditmm == 0  // excluding male borrowing households with loans in round 1 
* set _Ww... village dummies to zero
* village 142 drops out 'cos male borrowing households

* Chemin's method 
* set village has female credit village dummies (_W*) to zero to predict propensity score
* then reset dummies to previous values
tempvar esample
gen `esample' = e(sample)
levelsof vill if `esample', local(village)
foreach i in `village' {		
	tempvar _`i'
	gen `_`i'' = _Wwvill_`i'
	qui capture replace _Wwvill_`i' = 0 
}
* predict propensity score without fillage fixed effects
predict ps
foreach i in `village' {		// replace recoded village dummies with original values
	drop _Wwvill_`i' 
	gen _Wwvill_`i' = `_`i''
}

* logit with borrowing round 1 dependent variabkle (fhh1) with MP vars  
logit fhh1 trlnd23 trlnd22 trlnd21 trlnd13 trlnd12 trlnd11 /// 
             loghland educhead sexhead agehead maxeducf maxeducm  ///
             noadultm nospouse _W* round2 round3 nontrgth noadultf if wchoice == 1 & thana <= 24 & mhh1 == 0  // 
* set _Ww... village dummies to zero
tempvar esample
gen `esample' = e(sample)
levelsof vill if `esample', local(village)
foreach i in `village' {		
	tempvar _`i'
	gen `_`i'' = _Wwvill_`i'
	qui capture replace _Wwvill_`i' = 0 
}
* predict propensity score without fillage fixed effects
predict ps1
foreach i in `village' {		// replace recoded village dummies with original values
	drop _Wwvill_`i' 
	gen _Wwvill_`i' = `_`i''
}

* remove village fixed effects from outcome variable 
* target households only in female credit villages without male borrowing or non-target households in control villages
reg lexptot ibn.vill if wchoice == 1 & thana <= 24 & creditmm == 0 & nontrgth == 0 | ~(nontrgth == 1 & thana >= 25) , nocons // 
predict e_lexptot, residuals


***********************************************************************************
* PSM with village fixed effects - Chemin's method
* ps is for Pitt's creditff variable - borrowing any round
* ps1 is for borrowing in round 1 only
***********************************************************************************
mat results = J(20, 8, .)

** kernel psm of e_lexptot 
* creditff
psmatch2 creditff if (creditff == 1  & creditmm == 0) | (thana > 24 & nontrgth == 0 ), /// 
             	out(e_lexptot) pscore(ps) kernel bwidth(.08) common
* table 2 row 1
store2 1 results	// table 2 row 1

* fhh1
psmatch2 fhh1 if (creditff == 1  & creditmm == 0) | (thana > 24 & nontrgth == 0),  ///
             	out(e_lexptot) pscore(ps1) kernel bwidth(.08) common
* 
store2 2 results 


** n(10)
* creditff
psmatch2 creditff if (creditff == 1  & creditmm == 0) | (thana > 24 & nontrgth == 0) , ///
             	out(e_lexptot) pscore(ps) n(10) common
* table 2 row 2
store2 3 results		// table 2 row 2
rsens_rpj e_lexptot if e(sample), gamma(1(.05)2) nn(10)
mat rsensvalues = r(rsensvalues)
sa_results 3 rsensvalues results

* fhh1 
psmatch2 fhh1 if (fhh1 == 1  & creditmm == 0) | (thana > 24 & nontrgth == 0 ) , ///
             	out(e_lexptot) pscore(ps1) n(10) common
store2 4 results 
rsens_rpj e_lexptot if e(sample), gamma(1(.05)2) nn(10)
mat rsensvalues = r(rsensvalues)
sa_results 4 rsensvalues results


** n(1)
* creditff
psmatch2 creditff if (creditff == 1  & creditmm == 0) | (thana > 24 & nontrgth == 0) , ///
             	out(e_lexptot) pscore(ps) n(1) common
* table 2 row 3
store2 5 results		// table 2 row 3
tempvar delta
gen `delta' = e_lexptot - _e_lexptot if _treat == 1 & _support == 1
rbounds `delta', gamma(1(.1)3)	/* not significant at gamma = 1.15 (10%) */
mat outmat = r(outmat)
sa_results 5 outmat results

* check rsens gives same values
rsens_rpj e_lexptot if e(sample), gamm(1(.05)1.5) nn(1)

* WHY DROP MALE ONLY VILLAGES (& why exclude nontrgth - but leave this till later)?

* psm of e_lexptot using kernel  
* creditff 
psmatch2 creditff if (creditff == 1  & creditmm == 0) | (creditmm == 0 & nontrgth == 0) , /// 
             	out(e_lexptot) pscore(ps) kernel bwidth(.08) common
* table 2 row 4
store2 6 results
* 142 drops out as no households with creditff == 1 & creditmm == 0 & nontrgth == 0

* same with n(10)
psmatch2 creditff if (creditff == 1  & creditmm == 0) | (creditmm == 0 & nontrgth == 0),  ///
             	out(e_lexptot) pscore(ps) n(10) common
* table 2 row 5
store2 7 results 
rsens e_lexptot if e(sample), gamma(1(.05)2) nn(10)
mat rsensvalues = r(rsensvalues)

sa_results 7 rsensvalues results


* n(1)
psmatch2 fhh1 if (fhh1== 1  & creditmm == 0) | (creditmm == 0 & nontrgth == 0) , ///
             	out(e_lexptot) pscore(ps1) n(1) common
store2 8 results
tempvar delta
gen `delta' = e_lexptot - _e_lexptot if _treat == 1 & _support == 1
rbounds `delta', gamma(1(.1)3)	 

mat outmat = r(outmat)

sa_results 8 outmat results

rsens e_lexptot if e(sample), gamm(1(.05)1.5) nn(1)
*/

* table of PSM with control villages 
*********************************************************
** Table 2 - village fixed effects only - full table below
*********************************************************
* mat list results
* esttab matrix(results, fmt(0 4 4 4 4 2 4 4 4 4)) using "${workingpath}\table2.csv", replace

/* 
Matrix row      table 2 row
1		1
2
3		2
4
5		3
6		4
7		5
8		6
*/

***********************************************************************************
* now use village covariates instead of village fixed effects
***********************************************************************************
* table 3
* get village covariates
preserve
	use "${villvarspath}\village.dta", clear
	gen vill = upzid * 10 + villid
	ren wave round
	sort vill round
	tempfile t
	save `t',replace
restore
sort vill round

merge m:1 vill round using `t'
tab _merge
drop _merge

* pitt vars excluding village fixed effects (_W*)
* include round dummies
global pittvars "trlnd23 trlnd22 trlnd21 trlnd13 trlnd12 trlnd11 loghland educhead sexhead agehead maxeducf maxeducm  noadultm   noadultf nospouse nontrgth round2 round3 " //
* exclude round dummies
global pittvars1 "trlnd23 trlnd22 trlnd21 trlnd13 trlnd12 trlnd11 loghland educhead sexhead agehead maxeducf maxeducm  noadultm noadultf nospouse nontrgth"
* drop nontrgth & noadultf
global pittvars2 "trlnd23 trlnd22 trlnd21 trlnd13 trlnd12 trlnd11 loghland educhead sexhead agehead maxeducf maxeducm  noadultm nospouse round2 round3 "


* add land values (from Land Values (Pitt, 1999))
sort nh round
preserve 
	use "${workingpath}\land_values.dta", clear
	sort nh 
	tempfile t
	save `t'
restore
merge m:1 nh using `t'
tab _merge
keep if _merge == 3 	// drop households with >5 acres
drop _merge

* Owned Cultivated land values
gen loghOwnedCultivated = ln(OwnedCultivated + 0.1)
gen loghTotOwned = ln(TotOwned + 0.1)

global rpjvars1 "trlnd23 trlnd22 trlnd21 trlnd13 trlnd12 trlnd11 educhead sexhead agehead maxeducf maxeducm  noadultm   noadultf nospouse  round2 round3 " // 

global villvars "devprg primcoed junrcoed highcoed highgirl highboys postsec schmohal ilmi hpruralh hpmatern hpfampln hpmidwif puccac bankc shopc hdqrc fprg velec pzrice pzwflour pzsugar pzsoil pzmoil pzhegg pzmilk pzonion pzgarlic pzturmer pzpotato pzgrnpep pzsalt pzbeef pzchick pzbsugar wagem wagef wagec"
global villvars1 "bankc fprg hdqrc highboys highcoed highgirl hpfampln hpmidwif hpruralh junrcoed hpmatern hpmidwif postsec puccac pzchick pzhegg pzmoil pzturmer shopc wagec"
* droppostsec
global villvars2 "bankc fprg hdqrc highboys highcoed highgirl hpfampln hpmidwif hpruralh junrcoed hpmatern hpmidwif puccac pzchick pzhegg pzmoil pzturmer shopc wagec"

************************************************************************
* treatment villages only
************************************************************************
* village fixed effects, unweighted
logit creditff $pittvars _W* if wchoice == 1 & creditmm == 0 
eststo _0, title("village covariates, treatment villages") 
predict ps_0

*                        weighted
logit creditff $pittvars _W* if wchoice == 1 & creditmm == 0 [pweight = weight]
eststo _0a, title("village covariates, treatment villages") 
predict ps_0a

* village covariates, unweighted 
logit creditff $pittvars $villvars2 if wchoice == 1 & creditmm == 0 
eststo _1, title("village covariates, treatment villages") 
predict ps_1

*                    weighted
logit creditff $pittvars $villvars2 if wchoice == 1 & creditmm == 0 [pweight = weight] 
eststo _1a, title("village covariates, treatment villages") 
predict ps_1a

* now all villages
* unweighted 
logit creditff $pittvars $villvars2 if creditmm == 0 
eststo _3, title("village covariates, weighted, treatment villages")
predict ps_2

*             weighted
logit creditff $pittvars $villvars2 if creditmm == 0 [pweight = weight] 
eststo _3a, title("village covariates, weighted, treatment villages")
predict ps_2a

* fhh1
* treatment villages
* village covariates, unweighted 
logit fhh1 $pittvars $villvars2 if wchoice == 1 & mhh1 == 0 
eststo _4, title("village covariates, treatment villages") 
predict ps_4

*                    weighted
logit fhh1 $pittvars $villvars2 if wchoice == 1 & mhh1 == 0 [pweight = weight] 
eststo _4a, title("village covariates, treatment villages") 
predict ps_4a


* now all villages
* unweighted 
logit fhh1 $pittvars $villvars2 if mhh1 == 0 
eststo _5, title("village covariates, weighted, treatment villages")
predict ps_3

*             weighted
logit fhh1 $pittvars $villvars2 if mhh1 == 0 [pweight = weight] 
eststo _5a, title("village covariates, weighted, treatment villages")
predict ps_5a

* now drop nontrgth
* fhh1
* treatment villages
* village covariates, unweighted 
logit fhh1 $pittvars2 $villvars2 if wchoice == 1 & mhh1 == 0 
eststo _6, title("village covariates, treatment villages") 
predict ps_6

*                    weighted
logit fhh1 $pittvars2 $villvars2 if wchoice == 1 & mhh1 == 0 [pweight = weight] 
eststo _6a, title("village covariates, treatment villages") 
predict ps_6a


* now all villages
* unweighted 
logit fhh1 $pittvars2 $villvars2 if mhh1 == 0 
eststo _7, title("village covariates, weighted, treatment villages")
predict ps_7

*             weighted
logit fhh1 $pittvars2 $villvars2 if mhh1 == 0 [pweight = weight] 
eststo _7a, title("village covariates, weighted, treatment villages")
predict ps_7a

* compare treatment villages only

**************************************************
* export to R - used with Match - nothing new    *
**************************************************
preserve
	keep if e(sample)
	keep nh vill thana creditff creditmm lexptot wchoice $pittvars $villvars2 weight  _W*
	ren _Ww* Ww*
	saveold "${workingpath}\pkexp4r.dta", replace
restore

**********************************************************************************
* village fixed effects, kernel, weighted logit
**********************************************************************************
mat resultsa = J(20, 10, .)
mat pstests = J(10, 8, .)
mat colnames pstests = chiprobaft r2aft chiprobbef r2bef medbiasaft meanbiasaft medbiasbef meanbiasbef


psmatch2 creditff if wchoice == 1 & creditmm == 0 , pscore("ps_0a") out(lexptot) kernel bwidth(.08) common
eststo _8, title("village fixed effects, kernel, treatment villages") 
* table 3 row 1
store 1 resultsa

pstest $pittvars if e(sample), both gr name(_1, replace) title(fixed effects) nodraw

local row = 1
local col = 1
foreach r in chiprobaft r2aft chiprobbef r2bef medbiasaft meanbiasaft medbiasbef meanbiasbef{
	mat pstests[`row', `col'] = r(`r') 
	local ++col
}
mat resultsa[1, 9] = pstests[1,  7]
mat resultsa[1, 10] = pstests[1,  5]

/*
qqcompare_rpj trlnd23 trlnd22 trlnd21 trlnd13 trlnd12 trlnd11 /// 
             loghland educhead agehead maxeducf maxeducm  ///
              , treatment(_treated) weight(_weight) precision(10)
catcompare sexhead ///
             noadultm nospouse noadultf nontrgth, treatment(_treated) weight(_weight) precision(0.01)
*/

* village fixed effects, n(10), weighted logit
psmatch2 creditff if wchoice == 1 & creditmm == 0 , pscore("ps_0a") out(lexptot) n(10) common quietly
eststo _8a, title("village fixed effects, kernel, treatment villages") 
* table 3 row 2
local row = 2
store `row' resultsa
rsens lexptot, gamma(1(.05)2) nn(10)
mat rsensvalues = r(rsensvalues)
sa_results `row' rsensvalues resultsa
pstest $pittvars if e(sample), both gr name(_1, replace) title(fixed effects) nodraw
local col = 1
foreach r in chiprobaft r2aft chiprobbef r2bef medbiasaft meanbiasaft medbiasbef meanbiasbef{
	mat pstests[`row', `col'] = r(`r') 
	local ++col
}
mat resultsa[`row', 9] = pstests[`row',  7]
mat resultsa[`row', 10] = pstests[`row',  5]

* village covariates,weighted logit, kernel
psmatch2 creditff if wchoice == 1 & creditmm == 0 , pscore(ps_1a) out(lexptot) kernel bwidth(.08) common
eststo _8b, title("village covariates, treatment villages")
* table 3 row 3
local row = 3
store `row' resultsa
pstest $pittvars if e(sample), both gr name(_2, replace)  title(village covariates) nodraw
local col = 1
foreach r in chiprobaft r2aft chiprobbef r2bef medbiasaft meanbiasaft medbiasbef meanbiasbef{
	mat pstests[`row', `col'] = r(`r') 
	local ++col
}
mat resultsa[`row', 9] = pstests[`row',  7]
mat resultsa[`row', 10] = pstests[`row',  5]

* village covariates,weighted logit, n(10)
psmatch2 creditff if wchoice == 1 & creditmm == 0 , pscore(ps_1a) out(lexptot) n(10) common
eststo _8b, title("village covariates, treatment villages")
* table 3 row 4
local row = 4
store `row' resultsa
rsens lexptot, gamma(1(.05)2) nn(10)
mat rsensvalues = r(rsensvalues)
sa_results `row' rsensvalues resultsa
pstest $pittvars if e(sample), both gr name(_2, replace)  title(village covariates) nodraw
local col = 1
foreach r in chiprobaft r2aft chiprobbef r2bef medbiasaft meanbiasaft medbiasbef meanbiasbef{
	mat pstests[`row', `col'] = r(`r') 
	local ++col
}
mat resultsa[`row', 9] = pstests[`row',  7]
mat resultsa[`row', 10] = pstests[`row',  5]

graph combine _1 _2, rows(2) imargin(zero) xsize(7.6) ysize(11.5)

/*
qqcompare_rpj trlnd23 trlnd22 trlnd21 trlnd13 trlnd12 trlnd11 /// 
             loghland educhead agehead maxeducf maxeducm  ///
              , treatment(_treated) weight(_weight) precision(10)

catcompare sexhead ///
             noadultm nospouse noadultf nontrgth, treatment(_treated) weight(_weight) precision(0.01)
*/

/*
qqtest $pittvars , treatment(creditff) weight(_weight) precision(0.01)
pstest $pittvars if e(sample), both
*/

**********************************************************************************
* all villages - village covariates 
**********************************************************************************
* kernel
psmatch2 creditff if creditmm == 0 , pscore(ps_2a) out(lexptot) kernel bwidth(.08) common
eststo _9, title("all villages, village covariates, weighted ")
* table 3 row 5
local row = 5
store `row' resultsa
pstest $pittvars if e(sample), both gr name(_3, replace)  title(all villages village covariates) nodraw
local col = 1
foreach r in chiprobaft r2aft chiprobbef r2bef medbiasaft meanbiasaft medbiasbef meanbiasbef{
	mat pstests[`row', `col'] = r(`r') 
	local ++col
}
mat resultsa[`row', 9] = pstests[`row',  7]
mat resultsa[`row', 10] = pstests[`row',  5]

/*
qqcompare $pittvars , treatment(creditff) weight(_weight) precision(0.01)
pstest $pittvars if e(sample), both
*/

* n(10) 
psmatch2 creditff if creditmm == 0 , pscore(ps_2a) out(lexptot) n(10) common
eststo _9a, title("all villages, n(10), weighted")
* table 3 row 6
local row = 6
store `row' resultsa
pstest $pittvars if e(sample), both gr name(_4, replace)  title(all villages village covariates) nodraw
local col = 1
foreach r in chiprobaft r2aft chiprobbef r2bef medbiasaft meanbiasaft medbiasbef meanbiasbef{
	mat pstests[`row', `col'] = r(`r') 
	local ++col
}
mat resultsa[`row', 9] = pstests[`row',  7]
mat resultsa[`row', 10] = pstests[`row',  5]
rsens_rpj lexptot, gamma(1(.05)2)
estadd r(rsensvalues)
mat rsensvalues = r(rsensvalues)
sa_results `row' rsensvalues resultsa

/*
qqtest $pittvars , treatment(creditff) weight(_weight) precision(0.01)
pstest $pittvars if e(sample), both
*/
* n(1)
psmatch2 creditff if creditmm == 0 , pscore(ps_2a) out(lexptot) n(1) common
eststo _10 , title("all villages, n(1), weighted")
* table 3 row 7
local row = 7
store `row' resultsa
pstest $pittvars if e(sample), both gr name(_4, replace)  title(all villages village covariates) nodraw
local col = 1
foreach r in chiprobaft r2aft chiprobbef r2bef medbiasaft meanbiasaft medbiasbef meanbiasbef{
	mat pstests[`row', `col'] = r(`r') 
	local ++col
}
mat resultsa[`row', 9] = pstests[`row',  7]
mat resultsa[`row', 10] = pstests[`row',  5]
tempvar delta
gen `delta' = lexptot - _lexptot if _treat == 1 & _support == 1
rbounds `delta', gamma(1(.1)2)	/* not significant at gamma =  */
estadd r(outmat)
mat outmat = r(outmat)
sa_results `row' outmat resultsa

** TABLE 2 with control villages & village covariates
mat colnames results = n diff sediff pdiff tdiff gamma siglo sighi
mat rownames results = chemin_kernel chemin_n10 chemin_n1
* mat list results , f(%7.4f)



** Table 3
* need to extract results
mat colnames resultsa = n diff sediff pdiff tdiff gamma siglo sighi medbiasbef medbiasaft
mat rownames resultsa = tr_vfe_kernel tr_vfe_n10 tr_covs_krnl tr_vfe_n10 a_covs_krnl a_covs_n10 all_covs_n1
mat list resultsa , f(%7.4f)
mat t = resultsa[1..7, 1]
* mat list t

*************************************************************************************
* Table 4 
*************************************************************************************
mat rownames pstests = "trkernelvfe" "trn10vfe" "trkernelvcov" "trn10vcov" "allkernelvcov" "alln10vcov"   "alln1vcov"
esttab matrix(pstests, fmt(4 4 4 4 4 4 ))

mat a =  pstests[1..., 8], pstests[1..., 6], pstests[1..., 7] , pstests[1..., 5], pstests[1...,3], pstests[1..., 1], pstests[1..., 4], pstests[1..., 2]

} // end quietly

*************************************************************************************
** TABLE 2 with control villages & village covariates
*************************************************************************************
esttab matrix(results, fmt(0 4 4 4 4 2 4 4)) using "${workingpath}\table2.csv", replace
/* 
Matrix row      table 2 row
1		1
2
3		2
4
5		3
6		4
7		5
8		6
*/

*************************************************************************************
** Table 3
*************************************************************************************
esttab matrix(resultsa, fmt(0 4 4 4 4 2 4 4 4 4))  using "${workingpath}\table3.csv", replace

*************************************************************************************
** table 4
*************************************************************************************
esttab matrix(a, fmt(3 3 3 3 3 3 3 3 )) using "${workingpath}\table4.csv" , replace
/*
Rows in matrixcorrespond to rows in table
matrix row	table row
1		1
2		2
3		3
4		4
5		5
6		6.....
*/

*****************************************************************************************
* Table 2, 3 & 4 are saved as "${workingpath}\table12/3/4.csv" -                        *
*****************************************************************************************




/*
* logits
esttab _0 _0a _1 _1a  _3 _3a _4 _4a _5 _5a _6 _6a, drop( o._Ww* _Ww* $villvars2 )

* PSM coefficients on treatment
esttab _8 _8a _9 _9a _10 , keep(_treated) t stats(N r2)

*/

